@@ -154,7 +154,7 @@ static void advance_buffer(aac_buffer *b, int bytes)
     while ((b->bytes_into_buffer > 0) && (bytes > 0))
     {
         int chunk = min(bytes, b->bytes_into_buffer);
-    
+
         bytes -= chunk;
         b->file_offset += chunk;
         b->bytes_consumed = chunk;
@@ -217,6 +217,8 @@ static int adts_parse(aac_buffer *b, int *bitrate, float *length)
 
             frame_length = ((((unsigned int)b->buffer[3] & 0x3)) << 11)
                 | (((unsigned int)b->buffer[4]) << 3) | (b->buffer[5] >> 5);
+            if (frame_length == 0)
+                break;
 
             t_framelength += frame_length;
 
@@ -697,6 +699,10 @@ static int decodeAACfile(char *aacfile, char *sndfile, char *adts_fn, int to_std
         /* update buffer indices */
         advance_buffer(&b, frameInfo.bytesconsumed);
 
+        /* check if the inconsistent number of channels */
+        if (aufile != NULL && frameInfo.channels != aufile->channels)
+            frameInfo.error = 12;
+
         if (frameInfo.error > 0)
         {
             faad_fprintf(stderr, "Error: %s\n",
@@ -872,7 +878,7 @@ static int decodeMP4file(char *mp4file, char *sndfile, char *adts_fn, int to_std
         if (NeAACDecAudioSpecificConfig(mp4config.asc.buf, mp4config.asc.size, &mp4ASC) >= 0)
         {
             if (mp4ASC.frameLengthFlag == 1) framesize = 960;
-            if (mp4ASC.sbr_present_flag == 1) framesize *= 2;
+            if (mp4ASC.sbr_present_flag == 1 || mp4ASC.forceUpSampling) framesize *= 2;
         }
     }
 
