@@ -1,19 +1,19 @@
 /*
 ** FAAD2 - Freeware Advanced Audio (AAC) Decoder including SBR decoding
 ** Copyright (C) 2003-2005 M. Bakker, Nero AG, http://www.nero.com
-**  
+**
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
 ** the Free Software Foundation; either version 2 of the License, or
 ** (at your option) any later version.
-** 
+**
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
-** 
+**
 ** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software 
+** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 **
 ** Any non-GPL usage of this software or parts of this software is strictly
@@ -344,7 +344,9 @@ static void decode_sce_lfe(NeAACDecStruct *hDecoder,
        can become 2 when some form of Parametric Stereo coding is used
     */
 
-    if (hDecoder->frame && hDecoder->element_id[hDecoder->fr_ch_ele] != id_syn_ele) {
+    if (hDecoder->element_id[hDecoder->fr_ch_ele] != INVALID_ELEMENT_ID &&
+        hDecoder->element_id[hDecoder->fr_ch_ele] != id_syn_ele)
+    {
         /* element inconsistency */
         hInfo->error = 21;
         return;
@@ -401,7 +403,9 @@ static void decode_cpe(NeAACDecStruct *hDecoder, NeAACDecFrameInfo *hInfo, bitfi
         return;
     }
 
-    if (hDecoder->frame && hDecoder->element_id[hDecoder->fr_ch_ele] != id_syn_ele) {
+    if (hDecoder->element_id[hDecoder->fr_ch_ele] != INVALID_ELEMENT_ID &&
+        hDecoder->element_id[hDecoder->fr_ch_ele] != id_syn_ele)
+    {
         /* element inconsistency */
         hInfo->error = 21;
         return;
@@ -535,37 +539,61 @@ void raw_data_block(NeAACDecStruct *hDecoder, NeAACDecFrameInfo *hInfo,
             break;
         case 3:
             decode_sce_lfe(hDecoder, hInfo, ld, ID_SCE);
+            if (hInfo->error > 0)
+                return;
             decode_cpe(hDecoder, hInfo, ld, ID_CPE);
             if (hInfo->error > 0)
                 return;
             break;
         case 4:
             decode_sce_lfe(hDecoder, hInfo, ld, ID_SCE);
+            if (hInfo->error > 0)
+                return;
             decode_cpe(hDecoder, hInfo, ld, ID_CPE);
+            if (hInfo->error > 0)
+                return;
             decode_sce_lfe(hDecoder, hInfo, ld, ID_SCE);
             if (hInfo->error > 0)
                 return;
             break;
         case 5:
             decode_sce_lfe(hDecoder, hInfo, ld, ID_SCE);
+            if (hInfo->error > 0)
+                return;
             decode_cpe(hDecoder, hInfo, ld, ID_CPE);
+            if (hInfo->error > 0)
+                return;
             decode_cpe(hDecoder, hInfo, ld, ID_CPE);
             if (hInfo->error > 0)
                 return;
             break;
         case 6:
             decode_sce_lfe(hDecoder, hInfo, ld, ID_SCE);
+            if (hInfo->error > 0)
+                return;
             decode_cpe(hDecoder, hInfo, ld, ID_CPE);
+            if (hInfo->error > 0)
+                return;
             decode_cpe(hDecoder, hInfo, ld, ID_CPE);
+            if (hInfo->error > 0)
+                return;
             decode_sce_lfe(hDecoder, hInfo, ld, ID_LFE);
             if (hInfo->error > 0)
                 return;
             break;
         case 7: /* 8 channels */
             decode_sce_lfe(hDecoder, hInfo, ld, ID_SCE);
+            if (hInfo->error > 0)
+                return;
             decode_cpe(hDecoder, hInfo, ld, ID_CPE);
+            if (hInfo->error > 0)
+                return;
             decode_cpe(hDecoder, hInfo, ld, ID_CPE);
+            if (hInfo->error > 0)
+                return;
             decode_cpe(hDecoder, hInfo, ld, ID_CPE);
+            if (hInfo->error > 0)
+                return;
             decode_sce_lfe(hDecoder, hInfo, ld, ID_LFE);
             if (hInfo->error > 0)
                 return;
@@ -884,7 +912,10 @@ static uint8_t ics_info(NeAACDecStruct *hDecoder, ic_stream *ics, bitfile *ld,
                     if ((ics->ltp.data_present = faad_get1bit(ld
                         DEBUGVAR(1,50,"ics_info(): ltp.data_present"))) & 1)
                     {
-                        ltp_data(hDecoder, ics, &(ics->ltp), ld);
+                        if ((retval = ltp_data(hDecoder, ics, &(ics->ltp), ld)) > 0)
+                        {
+                            return retval;
+                        }
                     }
                 }
 #endif
@@ -1091,6 +1122,8 @@ static uint8_t fill_element(NeAACDecStruct *hDecoder, bitfile *ld, drc_info *drc
 #endif
                     );
             }
+            if (!hDecoder->sbr[sbr_ele])
+                return 19;
 
             hDecoder->sbr_present_flag = 1;
 
@@ -1279,7 +1312,7 @@ void DRM_aac_scalable_main_element(NeAACDecStruct *hDecoder, NeAACDecFrameInfo *
     }
 #else
     faad_get1bit(ld);
-#endif    
+#endif
 
     hInfo->error = side_info(hDecoder, &cpe, ld, ics1, 1);
     if (hInfo->error > 0)
@@ -1360,6 +1393,11 @@ void DRM_aac_scalable_main_element(NeAACDecStruct *hDecoder, NeAACDecFrameInfo *
             hDecoder->sbr[0] = sbrDecodeInit(hDecoder->frameLength, hDecoder->element_id[0],
                 2*get_sample_rate(hDecoder->sf_index), 0 /* ds SBR */, 1);
         }
+        if (!hDecoder->sbr[0])
+        {
+            hInfo->error = 19;
+            return;
+        }
 
         /* Reverse bit reading of SBR data in DRM audio frame */
         revbuffer = (uint8_t*)faad_malloc(buffer_size*sizeof(uint8_t));
@@ -1611,7 +1649,7 @@ static uint8_t individual_channel_stream(NeAACDecStruct *hDecoder, element *ele,
     if (result > 0)
         return result;
 
-    if (hDecoder->object_type >= ER_OBJECT_START) 
+    if (hDecoder->object_type >= ER_OBJECT_START)
     {
         if (ics->tns_data_present)
             tns_data(ics, &(ics->tns), ld);
@@ -2179,11 +2217,11 @@ static uint16_t extension_payload(bitfile *ld, drc_info *drc, uint16_t count)
         return n;
     case EXT_FILL_DATA:
         /* fill_nibble = */ faad_getbits(ld, 4
-            DEBUGVAR(1,136,"extension_payload(): fill_nibble")); /* must be 0000 */
+            DEBUGVAR(1,136,"extension_payload(): fill_nibble")); /* must be '0000' */
         for (i = 0; i < count-1; i++)
         {
             /* fill_byte[i] = */ faad_getbits(ld, 8
-                DEBUGVAR(1,88,"extension_payload(): fill_byte")); /* must be 10100101 */
+                DEBUGVAR(1,88,"extension_payload(): fill_byte")); /* must be '10100101' */
         }
         return count;
     case EXT_DATA_ELEMENT:
@@ -2642,7 +2680,7 @@ uint32_t faad_latm_frame(latm_header *latm, bitfile *ld)
         endpos = faad_get_processed_bits(ld);
         if(ret>0)
             return (len*8)-(endpos-initpos);
-        //faad_getbits(ld, initpos-endpos); //go back to initpos, but is valid a getbits(-N) ? 
+        //faad_getbits(ld, initpos-endpos); //go back to initpos, but is valid a getbits(-N) ?
     }
     return 0xFFFFFFFF;
 }
